@@ -61,7 +61,7 @@ class PageGtk(PageBase):
 
             # Populate drop-down
             self.model_interface = gtk.ListStore(str)
-            for line in subprocess.Popen(['nmcli','-t','-f','DEVICE,STATE','dev'],stderr=subprocess.PIPE,stdout=subprocess.PIPE).stdout.readlines():
+            for line in sorted(subprocess.Popen(['nmcli','-t','-f','DEVICE,TYPE','dev'],stderr=subprocess.PIPE,stdout=subprocess.PIPE).stdout.readlines()):
                 info=line.strip().split(':')
                 self.model_interface.append(["%s (%s)" % (info[0],info[1])])
             self.ltsp_interface.set_model(self.model_interface)
