@@ -45,7 +45,7 @@ class PackagesModel(gtk.TreeStore):
 
     def populate_tree(self):
         src_pkg = "edubuntu-meta"
-        meta_blacklist = ['edubuntu-server','edubuntu-desktop-kde']
+        meta_blacklist = ['edubuntu-server','edubuntu-desktop-kde','edubuntu-fonts']
         package_blacklist = ['unity-2d']
         relation_blacklist = ['Depends']
 
@@ -72,23 +72,33 @@ class PackagesModel(gtk.TreeStore):
         ubiquity_blacklist=install_misc.query_recorded_removed()[1]
         ubiquity_whitelist=install_misc.query_recorded_installed()
 
-        for pkg in cache.packages:
-            if pkg.name in srcpkgrecords.binaries and not pkg.name in meta_blacklist:
+        processed = []
+        for pkg in sorted(cache.packages, key=lambda package: package.name):
+            if pkg.name in srcpkgrecords.binaries and not pkg.name in meta_blacklist and not pkg.name in processed:
                 pkgrecords.lookup(pkg.version_list[0].file_list[0])
                 piter=self.append(None,(True,pkg.name,pkgrecords.short_desc))
                 for dep_type in pkg.version_list[0].depends_list:
                     if dep_type in relation_blacklist:
                         continue
 
-                    for bin_pkg in pkg.version_list[0].depends_list[dep_type]:
+                    for bin_pkg in sorted(pkg.version_list[0].depends_list[dep_type], key=lambda package: package[0].target_pkg.name):
                         if bin_pkg[0].target_pkg.name in package_blacklist:
                             continue
 
-                        pkgrecords.lookup(bin_pkg[0].target_pkg.version_list[0].file_list[0])
+                        # Don't list inter meta package dependencies unless it's a meta package we don't list
+                        if bin_pkg[0].target_pkg.name in (set(srcpkgrecords.binaries) - set(meta_blacklist)):
+                            continue
+
+                        try:
+                            pkgrecords.lookup(bin_pkg[0].target_pkg.version_list[0].file_list[0])
+                        except IndexError:
+                            continue
+
                         if (bin_pkg[0].target_pkg.current_state == apt_pkg.CURSTATE_INSTALLED and bin_pkg[0].target_pkg.name not in ubiquity_blacklist) or bin_pkg[0].target_pkg.name in ubiquity_whitelist:
                             self.append(piter,(True,bin_pkg[0].target_pkg.name,pkgrecords.short_desc))
                         else:
                             self.append(piter,(False,bin_pkg[0].target_pkg.name,pkgrecords.short_desc))
+                processed.append(pkg.name)
 
 class PageBase(PluginUI):
     pass
